@@ -2,6 +2,8 @@
 #' @export
 #' @rdname coord_map
 coord_quickmap <- function(xlim = NULL, ylim = NULL, expand = TRUE, clip = "on") {
+  check_coord_limits(xlim)
+  check_coord_limits(ylim)
   ggproto(NULL, CoordQuickmap,
     limits = list(x = xlim, y = ylim),
     expand = expand,
@@ -25,7 +27,7 @@ CoordQuickmap <- ggproto("CoordQuickmap", CoordCartesian,
     x.dist <- dist_central_angle(x.center + c(-0.5, 0.5), rep(y.center, 2))
     y.dist <- dist_central_angle(rep(x.center, 2), y.center + c(-0.5, 0.5))
     # NB: this makes the projection correct in the center of the plot and
-    #     increasingly less correct towards the edges. For regions of reasonnable
+    #     increasingly less correct towards the edges. For regions of reasonable
     #     size, this seems to give better results than computing this ratio from
     #     the total lat and lon span.
 
