@@ -23,17 +23,37 @@
 #'    the plot data. The return value must be a `data.frame`, and
 #'    will be used as the layer data. A `function` can be created
 #'    from a `formula` (e.g. `~ head(.x, 10)`).
-#' @param geom The geometric object to use to display the data, either as a
-#'   `ggproto` `Geom` subclass or as a string naming the geom stripped of the
-#'   `geom_` prefix (e.g. `"point"` rather than `"geom_point"`)
-#' @param stat The statistical transformation to use on the data for this
-#'    layer, either as a `ggproto` `Geom` subclass or as a string naming the
-#'    stat stripped of the `stat_` prefix (e.g. `"count"` rather than
-#'    `"stat_count"`)
-#' @param position Position adjustment, either as a string naming the adjustment
-#'   (e.g. `"jitter"` to use `position_jitter`), or the result of a call to a
-#'   position adjustment function. Use the latter if you need to change the
-#'   settings of the adjustment.
+#'
+#' @param geom The geometric object to use to display the data for this layer.
+#'   When using a `stat_*()` function to construct a layer, the `geom` argument
+#'   can be used to override the default coupling between stats and geoms. The
+#'   `geom` argument accepts the following:
+#'   * A `Geom` ggproto subclass, for example `GeomPoint`.
+#'   * A string naming the geom. To give the geom as a string, strip the
+#'     function name of the `geom_` prefix. For example, to use `geom_point()`,
+#'     give the geom as `"point"`.
+#'   * For more information and other ways to specify the geom, see the
+#'     [layer geom][layer_geoms] documentation.
+#' @param stat The statistical transformation to use on the data for this layer.
+#'   When using a `geom_*()` function to construct a layer, the `stat`
+#'   argument can be used the override the default coupling between geoms and
+#'   stats. The `stat` argument accepts the following:
+#'   * A `Stat` ggproto subclass, for example `StatCount`.
+#'   * A string naming the stat. To give the stat as a string, strip the
+#'     function name of the `stat_` prefix. For example, to use `stat_count()`,
+#'     give the stat as `"count"`.
+#'   * For more information and other ways to specify the stat, see the
+#'     [layer stat][layer_stats] documentation.
+#' @param position A position adjustment to use on the data for this layer. This
+#'   can be used in various ways, including to prevent overplotting and
+#'   improving the display. The `position` argument accepts the following:
+#'   * The result of calling a position function, such as `position_jitter()`.
+#'     This method allows for passing extra arguments to the position.
+#'   * A string naming the position adjustment. To give the position as a
+#'     string, strip the function name of the `position_` prefix. For example,
+#'     to use `position_jitter()`, give the position as `"jitter"`.
+#'   * For more information and other ways to specify the position, see the
+#'     [layer position][layer_positions] documentation.
 #' @param show.legend logical. Should this layer be included in the legends?
 #'   `NA`, the default, includes if any aesthetics are mapped.
 #'   `FALSE` never includes, and `TRUE` always includes.
@@ -49,9 +69,12 @@
 #' @param params Additional parameters to the `geom` and `stat`.
 #' @param key_glyph A legend key drawing function or a string providing the
 #'   function name minus the `draw_key_` prefix. See [draw_key] for details.
-#' @param layer_class The type of layer object to be constructued. This is
+#' @param layer_class The type of layer object to be constructed. This is
 #'   intended for ggplot2 internal use only.
 #' @keywords internal
+#' @seealso
+#' The `r link_book(c("plot building chapter", "geoms chapter"), c("layers", "individual-geoms"))`
+#' @family layer documentation
 #' @examples
 #' # geom calls are just a short cut for layer
 #' ggplot(mpg, aes(displ, hwy)) + geom_point()
@@ -124,6 +147,12 @@ layer <- function(geom = NULL, stat = NULL,
 
   all <- c(geom$parameters(TRUE), stat$parameters(TRUE), geom$aesthetics())
 
+  # Take care of plain patterns provided as aesthetic
+  pattern <- vapply(aes_params, is_pattern, logical(1))
+  if (any(pattern)) {
+    aes_params[pattern] <- lapply(aes_params[pattern], list)
+  }
+
   # Warn about extra params and aesthetics
   extra_param <- setdiff(names(params), all)
   # Take care of size->linewidth renaming in layer params
@@ -171,7 +200,7 @@ layer <- function(geom = NULL, stat = NULL,
 
 validate_mapping <- function(mapping, call = caller_env()) {
   if (!inherits(mapping, "uneval")) {
-    msg <- paste0("{.arg mapping} must be created by {.fn aes}")
+    msg <- "{.arg mapping} must be created by {.fn aes}."
     # Native pipe have higher precedence than + so any type of gg object can be
     # expected here, not just ggplot
     if (inherits(mapping, "gg")) {
@@ -221,7 +250,7 @@ Layer <- ggproto("Layer", NULL,
     } else if (is.function(self$data)) {
       data <- self$data(plot_data)
       if (!is.data.frame(data)) {
-        cli::cli_abort("{.fn layer_data} must return a {.cls data.frame}")
+        cli::cli_abort("{.fn layer_data} must return a {.cls data.frame}.")
       }
     } else {
       data <- self$data
@@ -268,13 +297,13 @@ Layer <- ggproto("Layer", NULL,
       aesthetics[["group"]] <- self$aes_params$group
     }
 
-    scales_add_defaults(plot$scales, data, aesthetics, plot$plot_env)
-
     # Evaluate aesthetics
     env <- child_env(baseenv(), stage = stage)
     evaled <- lapply(aesthetics, eval_tidy, data = data, env = env)
     evaled <- compact(evaled)
 
+    plot$scales$add_defaults(evaled, plot$plot_env)
+
     # Check for discouraged usage in mapping
     warn_for_aes_extract_usage(aesthetics, data[setdiff(names(data), "PANEL")])
 
@@ -292,15 +321,23 @@ Layer <- ggproto("Layer", NULL,
     }
 
     n <- nrow(data)
+    aes_n <- lengths(evaled)
     if (n == 0) {
       # No data, so look at longest evaluated aesthetic
       if (length(evaled) == 0) {
         n <- 0
       } else {
-        aes_n <- lengths(evaled)
         n <- if (min(aes_n) == 0) 0L else max(aes_n)
       }
     }
+    if ((self$geom$check_constant_aes %||% TRUE)
+        && length(aes_n) > 0 && all(aes_n == 1) && n > 1) {
+      cli::cli_warn(c(
+        "All aesthetics have length 1, but the data has {n} rows.",
+        i = "Please consider using {.fn annotate} or provide this layer \\
+        with data containing a single row."
+      ), call = self$constructor)
+    }
     check_aesthetics(evaled, n)
 
     # Set special group and panel vars
@@ -341,7 +378,7 @@ Layer <- ggproto("Layer", NULL,
     if (length(new) == 0) return(data)
 
     # data needs to be non-scaled
-    data_orig <- scales_backtransform_df(plot$scales, data)
+    data_orig <- plot$scales$backtransform_df(data)
 
     # Add map stat output to aesthetics
     env <- child_env(baseenv(), stat = stat, after_stat = after_stat)
@@ -369,11 +406,11 @@ Layer <- ggproto("Layer", NULL,
     stat_data <- data_frame0(!!!compact(stat_data))
 
     # Add any new scales, if needed
-    scales_add_defaults(plot$scales, data, new, plot$plot_env)
+    plot$scales$add_defaults(stat_data, plot$plot_env)
     # Transform the values, if the scale say it's ok
     # (see stat_spoke for one exception)
     if (self$stat$retransform) {
-      stat_data <- scales_transform_df(plot$scales, stat_data)
+      stat_data <- plot$scales$transform_df(stat_data)
     }
 
     cunion(stat_data, data)
@@ -438,7 +475,7 @@ check_subclass <- function(x, subclass,
     obj <- find_global(name, env = env)
 
     if (is.null(obj) || !inherits(obj, subclass)) {
-      cli::cli_abort("Can't find {argname} called {.val {x}}", call = call)
+      cli::cli_abort("Can't find {argname} called {.val {x}}.", call = call)
     } else {
       obj
     }
