@@ -6,9 +6,12 @@
 # This includes managing the parameters for the facet and the coord
 # so that we don't modify the ggproto object in place.
 
-create_layout <- function(facet = FacetNull, coord = CoordCartesian) {
-  ggproto(NULL, Layout, facet = facet, coord = coord)
+create_layout <- function(facet, coord, layout = NULL) {
+  layout <- layout %||% Layout
+  check_inherits(layout, "Layout")
+  ggproto(NULL, layout, facet = facet, coord = coord)
 }
+
 #' @rdname ggplot2-ggproto
 #' @format NULL
 #' @usage NULL
@@ -106,8 +109,8 @@ Layout <- ggproto("Layout", NULL,
     # Draw individual labels, then add to gtable
     labels <- self$coord$labels(
       list(
-        x = self$xlabel(labels),
-        y = self$ylabel(labels)
+        x = self$resolve_label(self$panel_scales_x[[1]], labels),
+        y = self$resolve_label(self$panel_scales_y[[1]], labels)
       ),
       self$panel_params[[1]]
     )
@@ -151,21 +154,29 @@ Layout <- ggproto("Layout", NULL,
     layout <- self$layout
 
     lapply(data, function(layer_data) {
-      match_id <- match(layer_data$PANEL, layout$PANEL)
+      match_id <- NULL
 
       # Loop through each variable, mapping across each scale, then joining
       # back together
       x_vars <- intersect(self$panel_scales_x[[1]]$aesthetics, names(layer_data))
-      names(x_vars) <- x_vars
-      SCALE_X <- layout$SCALE_X[match_id]
-      new_x <- scale_apply(layer_data, x_vars, "map", SCALE_X, self$panel_scales_x)
-      layer_data[, x_vars] <- new_x
+      if (length(x_vars) > 0) {
+        match_id <- match(layer_data$PANEL, layout$PANEL)
+        names(x_vars) <- x_vars
+        SCALE_X <- layout$SCALE_X[match_id]
+        new_x <- scale_apply(layer_data, x_vars, "map", SCALE_X, self$panel_scales_x)
+        layer_data[, x_vars] <- new_x
+      }
 
       y_vars <- intersect(self$panel_scales_y[[1]]$aesthetics, names(layer_data))
-      names(y_vars) <- y_vars
-      SCALE_Y <- layout$SCALE_Y[match_id]
-      new_y <- scale_apply(layer_data, y_vars, "map", SCALE_Y, self$panel_scales_y)
-      layer_data[, y_vars] <- new_y
+      if (length(y_vars) > 0) {
+        if (is.null(match_id)) {
+          match_id <- match(layer_data$PANEL, layout$PANEL)
+        }
+        names(y_vars) <- y_vars
+        SCALE_Y <- layout$SCALE_Y[match_id]
+        new_y <- scale_apply(layer_data, y_vars, "map", SCALE_Y, self$panel_scales_y)
+        layer_data[, y_vars] <- new_y
+      }
 
       layer_data
     })
@@ -212,7 +223,7 @@ Layout <- ggproto("Layout", NULL,
     invisible()
   },
 
-  setup_panel_guides = function(self, guides, layers, default_mapping) {
+  setup_panel_guides = function(self, guides, layers) {
     self$panel_params <- lapply(
       self$panel_params,
       self$coord$setup_panel_guides,
@@ -224,37 +235,43 @@ Layout <- ggproto("Layout", NULL,
       self$panel_params,
       self$coord$train_panel_guides,
       layers,
-      default_mapping,
       self$coord_params
     )
 
     invisible()
   },
 
-  xlabel = function(self, labels) {
-    primary <- self$panel_scales_x[[1]]$name %|W|% labels$x
-    primary <- self$panel_scales_x[[1]]$make_title(primary)
-    secondary <- if (is.null(self$panel_scales_x[[1]]$secondary.axis)) {
+  resolve_label = function(self, scale, labels) {
+    # General order is: guide title > scale name > labels
+    aes       <- scale$aesthetics[[1]]
+    primary   <- scale$name %|W|% labels[[aes]]
+    secondary <- if (is.null(scale$secondary.axis)) {
       waiver()
     } else {
-      self$panel_scales_x[[1]]$sec_name()
-    } %|W|% labels$sec.x
+      scale$sec_name()
+    } %|W|% labels[[paste0("sec.", aes)]]
     if (is.derived(secondary)) secondary <- primary
-    secondary <- self$panel_scales_x[[1]]$make_sec_title(secondary)
-    list(primary = primary, secondary = secondary)[self$panel_scales_x[[1]]$axis_order()]
-  },
+    order <- scale$axis_order()
 
-  ylabel = function(self, labels) {
-    primary <- self$panel_scales_y[[1]]$name %|W|% labels$y
-    primary <- self$panel_scales_y[[1]]$make_title(primary)
-    secondary <- if (is.null(self$panel_scales_y[[1]]$secondary.axis)) {
-      waiver()
-    } else {
-      self$panel_scales_y[[1]]$sec_name()
-    } %|W|% labels$sec.y
-    if (is.derived(secondary)) secondary <- primary
-    secondary <- self$panel_scales_y[[1]]$make_sec_title(secondary)
-    list(primary = primary, secondary = secondary)[self$panel_scales_y[[1]]$axis_order()]
+    if (!is.null(self$panel_params[[1]]$guides)) {
+      if ((scale$position) %in% c("left", "right")) {
+        guides <- c("y", "y.sec")
+      } else {
+        guides <- c("x", "x.sec")
+      }
+      params    <- self$panel_params[[1]]$guides$get_params(guides)
+      if (!is.null(params)) {
+        primary   <- params[[1]]$title %|W|% primary
+        secondary <- params[[2]]$title %|W|% secondary
+        position  <- params[[1]]$position %||% scale$position
+        if (position != scale$position) {
+          order <- rev(order)
+        }
+      }
+    }
+    primary   <- scale$make_title(primary)
+    secondary <- scale$make_sec_title(secondary)
+    list(primary = primary, secondary = secondary)[order]
   },
 
   render_labels = function(self, labels, theme) {
@@ -292,8 +309,8 @@ scale_apply <- function(data, vars, method, scale_id, scales) {
   if (length(vars) == 0) return()
   if (nrow(data) == 0) return()
 
-  if (any(is.na(scale_id))) {
-    cli::cli_abort("{.arg scale_id} must not contain any {.val NA}")
+  if (anyNA(scale_id)) {
+    cli::cli_abort("{.arg scale_id} must not contain any {.val NA}.")
   }
 
   scale_index <- split_with_index(seq_along(scale_id), scale_id, length(scales))
