@@ -3,10 +3,14 @@
 #' Based on [gray.colors()]. This is black and white equivalent
 #' of [scale_colour_gradient()].
 #'
-#' @inheritParams scales::grey_pal
+#' @inheritParams scales::pal_grey
 #' @inheritParams scale_colour_hue
-#' @inheritDotParams discrete_scale
+#' @inheritDotParams discrete_scale -expand -position -scale_name
 #' @family colour scales
+#' @seealso
+#' The documentation on [colour aesthetics][aes_colour_fill_alpha].
+#'
+#' The `r link_book("hue and grey scales section", "scales-colour#hue-and-grey-scales")`
 #' @rdname scale_grey
 #' @export
 #' @examples
@@ -25,14 +29,22 @@
 #' ggplot(mtcars, aes(mpg, wt)) +
 #'   geom_point(aes(colour = miss)) +
 #'   scale_colour_grey(na.value = "green")
-scale_colour_grey <- function(..., start = 0.2, end = 0.8, na.value = "red", aesthetics = "colour") {
-  discrete_scale(aesthetics, "grey", grey_pal(start, end),
-    na.value = na.value, ...)
+scale_colour_grey <- function(name = waiver(), ..., start = 0.2, end = 0.8,
+                              na.value = "red", aesthetics = "colour") {
+  discrete_scale(
+    aesthetics, name = name,
+    palette = pal_grey(start, end),
+    na.value = na.value, ...
+  )
 }
 
 #' @rdname scale_grey
 #' @export
-scale_fill_grey <- function(..., start = 0.2, end = 0.8, na.value = "red", aesthetics = "fill") {
-  discrete_scale(aesthetics, "grey", grey_pal(start, end),
-    na.value = na.value, ...)
+scale_fill_grey <- function(name = waiver(), ..., start = 0.2, end = 0.8,
+                            na.value = "red", aesthetics = "fill") {
+  discrete_scale(
+    aesthetics, name = name,
+    palette = pal_grey(start, end),
+    na.value = na.value, ...
+  )
 }
