@@ -62,9 +62,7 @@ NULL
 #' @rdname summarise_plot
 #' @export
 summarise_layout = function(p) {
-  if (!inherits(p, "ggplot_built")) {
-    cli::cli_abort("{.arg p} must be a {.cls ggplot_build} object")
-  }
+  check_inherits(p, "ggplot_built")
   l <- p$layout
 
   layout <- l$layout
@@ -101,9 +99,7 @@ summarise_layout = function(p) {
 #' @rdname summarise_plot
 #' @export
 summarise_coord = function(p) {
-  if (!inherits(p, "ggplot_built")) {
-    cli::cli_abort("{.arg p} must be a {.cls ggplot_build} object")
-  }
+  check_inherits(p, "ggplot_built")
 
   # Given a transform object, find the log base; if the transform object is
   # NULL, or if it's not a log transform, return NA.
@@ -126,9 +122,7 @@ summarise_coord = function(p) {
 #' @rdname summarise_plot
 #' @export
 summarise_layers <- function(p) {
-  if (!inherits(p, "ggplot_built")) {
-    cli::cli_abort("{.arg p} must be a {.cls ggplot_build} object")
-  }
+  check_inherits(p, "ggplot_built")
 
   # Default mappings. Make sure it's a regular list instead of an uneval
   # object.
