@@ -8,6 +8,8 @@
 #' @param x numeric vector
 #' @param zero should a zero value be automatically included in the
 #'   computation of resolution
+#' @param discrete should vectors mapped with a discrete scale be treated as
+#'   having a resolution of 1?
 #' @export
 #' @examples
 #' resolution(1:10)
@@ -17,14 +19,19 @@
 #' # Note the difference between numeric and integer vectors
 #' resolution(c(2, 10, 20, 50))
 #' resolution(c(2L, 10L, 20L, 50L))
-resolution <- function(x, zero = TRUE) {
-  if (is.integer(x) || zero_range(range(x, na.rm = TRUE)))
+resolution <- function(x, zero = TRUE, discrete = FALSE) {
+  if (is.integer(x) || zero_range(range(x, na.rm = TRUE))) {
     return(1)
+  }
+  if (discrete && is_mapped_discrete(x)) {
+    return(1)
+  }
 
   x <- unique0(as.numeric(x))
   if (zero) {
     x <- unique0(c(0, x))
   }
-
-  min(diff(sort(x)))
+  d <- diff(sort(x))
+  tolerance <- sqrt(.Machine$double.eps)
+  min(d[d > tolerance])
 }
