@@ -1,8 +1,8 @@
-## ---- include = FALSE----------------------------------------------------
+## ----include = FALSE----------------------------------------------------------
 knitr::opts_chunk$set(collapse = TRUE, comment = "#>", fig.width = 7, fig.height = 7, fig.align = "center")
 library(ggplot2)
 
-## ----ggproto-intro-------------------------------------------------------
+## ----ggproto-intro------------------------------------------------------------
 A <- ggproto("A", NULL,
   x = 1,
   inc = function(self) {
@@ -16,7 +16,7 @@ A$inc()
 A$inc()
 A$x
 
-## ----chull---------------------------------------------------------------
+## ----chull--------------------------------------------------------------------
 StatChull <- ggproto("StatChull", Stat,
   compute_group = function(data, scales) {
     data[chull(data$x, data$y), , drop = FALSE]
@@ -25,7 +25,7 @@ StatChull <- ggproto("StatChull", Stat,
   required_aes = c("x", "y")
 )
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 stat_chull <- function(mapping = NULL, data = NULL, geom = "polygon",
                        position = "identity", na.rm = FALSE, show.legend = NA, 
                        inherit.aes = TRUE, ...) {
@@ -36,22 +36,22 @@ stat_chull <- function(mapping = NULL, data = NULL, geom = "polygon",
   )
 }
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 ggplot(mpg, aes(displ, hwy)) + 
   geom_point() + 
   stat_chull(fill = NA, colour = "black")
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 ggplot(mpg, aes(displ, hwy, colour = drv)) + 
   geom_point() + 
   stat_chull(fill = NA)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 ggplot(mpg, aes(displ, hwy)) + 
   stat_chull(geom = "point", size = 4, colour = "red") +
   geom_point()
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 StatLm <- ggproto("StatLm", Stat, 
   required_aes = c("x", "y"),
   
@@ -80,7 +80,7 @@ ggplot(mpg, aes(displ, hwy)) +
   geom_point() + 
   stat_lm()
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 StatLm <- ggproto("StatLm", Stat, 
   required_aes = c("x", "y"),
   
@@ -111,7 +111,7 @@ ggplot(mpg, aes(displ, hwy)) +
   stat_lm(formula = y ~ poly(x, 10)) + 
   stat_lm(formula = y ~ poly(x, 10), geom = "point", colour = "red", n = 20)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 #' @export
 #' @inheritParams ggplot2::stat_identity
 #' @param formula The modelling formula passed to \code{lm}. Should only 
@@ -129,7 +129,7 @@ stat_lm <- function(mapping = NULL, data = NULL, geom = "line",
 }
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 StatDensityCommon <- ggproto("StatDensityCommon", Stat, 
   required_aes = "x",
   
@@ -169,10 +169,10 @@ ggplot(mpg, aes(displ, colour = drv)) +
 ggplot(mpg, aes(displ, colour = drv)) + 
   stat_density_common(bandwidth = 0.5)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 StatDensityCommon <- ggproto("StatDensity2", Stat, 
   required_aes = "x",
-  default_aes = aes(y = stat(density)),
+  default_aes = aes(y = after_stat(density)),
 
   compute_group = function(data, scales, bandwidth = 1) {
     d <- density(data$x, bw = bandwidth)
@@ -180,17 +180,17 @@ StatDensityCommon <- ggproto("StatDensity2", Stat,
   }  
 )
 
-ggplot(mpg, aes(displ, drv, colour = stat(density))) + 
+ggplot(mpg, aes(displ, drv, colour = after_stat(density))) + 
   stat_density_common(bandwidth = 1, geom = "point")
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 ggplot(mpg, aes(displ, fill = drv)) + 
   stat_density_common(bandwidth = 1, geom = "area", position = "stack")
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 StatDensityCommon <- ggproto("StatDensityCommon", Stat, 
   required_aes = "x",
-  default_aes = aes(y = stat(density)),
+  default_aes = aes(y = after_stat(density)),
 
   setup_params = function(data, params) {
     min <- min(data$x) - 3 * params$bandwidth
@@ -212,10 +212,10 @@ StatDensityCommon <- ggproto("StatDensityCommon", Stat,
 
 ggplot(mpg, aes(displ, fill = drv)) + 
   stat_density_common(bandwidth = 1, geom = "area", position = "stack")
-ggplot(mpg, aes(displ, drv, fill = stat(density))) + 
+ggplot(mpg, aes(displ, drv, fill = after_stat(density))) + 
   stat_density_common(bandwidth = 1, geom = "raster")
 
-## ----GeomSimplePoint-----------------------------------------------------
+## ----GeomSimplePoint----------------------------------------------------------
 GeomSimplePoint <- ggproto("GeomSimplePoint", Geom,
   required_aes = c("x", "y"),
   default_aes = aes(shape = 19, colour = "black"),
@@ -244,12 +244,12 @@ geom_simple_point <- function(mapping = NULL, data = NULL, stat = "identity",
 ggplot(mpg, aes(displ, hwy)) + 
   geom_simple_point()
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 GeomSimplePolygon <- ggproto("GeomPolygon", Geom,
   required_aes = c("x", "y"),
   
   default_aes = aes(
-    colour = NA, fill = "grey20", size = 0.5,
+    colour = NA, fill = "grey20", linewidth = 0.5,
     linetype = 1, alpha = 1
   ),
 
@@ -269,7 +269,7 @@ GeomSimplePolygon <- ggproto("GeomPolygon", Geom,
       gp = grid::gpar(
         col = first_row$colour,
         fill = scales::alpha(first_row$fill, first_row$alpha),
-        lwd = first_row$size * .pt,
+        lwd = first_row$linewidth * .pt,
         lty = first_row$linetype
       )
     )
@@ -289,9 +289,9 @@ ggplot(mpg, aes(displ, hwy)) +
   geom_point() + 
   geom_simple_polygon(aes(colour = class), fill = NA)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 GeomPolygonHollow <- ggproto("GeomPolygonHollow", GeomPolygon,
-  default_aes = aes(colour = "black", fill = NA, size = 0.5, linetype = 1,
+  default_aes = aes(colour = "black", fill = NA, linewidth = 0.5, linetype = 1,
     alpha = NA)
   )
 geom_chull <- function(mapping = NULL, data = NULL, 
@@ -308,17 +308,32 @@ ggplot(mpg, aes(displ, hwy)) +
   geom_point() + 
   geom_chull()
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
+StatBoxplot$setup_params
+
+## -----------------------------------------------------------------------------
+StatBoxplot$setup_data
+
+## -----------------------------------------------------------------------------
+GeomBoxplot$setup_data
+
+## -----------------------------------------------------------------------------
+GeomBoxplot$required_aes
+
+## -----------------------------------------------------------------------------
+GeomLine$setup_params
+
+## -----------------------------------------------------------------------------
 theme_grey()$legend.key
 
 new_theme <- theme_grey() + theme(legend.key = element_rect(colour = "red"))
 new_theme$legend.key
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 new_theme <- theme_grey() %+replace% theme(legend.key = element_rect(colour = "red"))
 new_theme$legend.key
 
-## ----axis-line-ex--------------------------------------------------------
+## ----axis-line-ex-------------------------------------------------------------
 df <- data.frame(x = 1:3, y = 1:3)
 base <- ggplot(df, aes(x, y)) + 
   geom_point() + 
@@ -327,12 +342,12 @@ base <- ggplot(df, aes(x, y)) +
 base
 base + theme(text = element_text(colour = "red"))
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 layout <- function(data, params) {
   data.frame(PANEL = c(1L, 2L), SCALE_X = 1L, SCALE_Y = 1L)
 }
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 mapping <- function(data, layout, params) {
   if (is.null(data) || nrow(data) == 0) {
     return(cbind(data, PANEL = integer(0)))
@@ -343,7 +358,7 @@ mapping <- function(data, layout, params) {
   )
 }
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 render <- function(panels, layout, x_scales, y_scales, ranges, coord, data,
                    theme, params) {
   # Place panels according to settings
@@ -415,7 +430,7 @@ render <- function(panels, layout, x_scales, y_scales, ranges, coord, data,
   panel_table
 }
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 # Constructor: shrink is required to govern whether scales are trained on 
 # Stat-transformed data or not.
 facet_duplicate <- function(horizontal = TRUE, shrink = TRUE) {
@@ -433,19 +448,19 @@ FacetDuplicate <- ggproto("FacetDuplicate", Facet,
   draw_panels = render
 )
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 p <- ggplot(mtcars, aes(x = hp, y = mpg)) + geom_point()
 p
 p + facet_duplicate()
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 library(scales)
 
 facet_trans <- function(trans, horizontal = TRUE, shrink = TRUE) {
   ggproto(NULL, FacetTrans,
     shrink = shrink,
     params = list(
-      trans = scales::as.trans(trans),
+      trans = scales::as.transform(trans),
       horizontal = horizontal
     )
   )
@@ -622,10 +637,10 @@ FacetTrans <- ggproto("FacetTrans", Facet,
   }
 )
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 ggplot(mtcars, aes(x = hp, y = mpg)) + geom_point() + facet_trans('sqrt')
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 facet_bootstrap <- function(n = 9, prop = 0.2, nrow = NULL, ncol = NULL, 
   scales = "fixed", shrink = TRUE, strip.position = "top") {
   
@@ -678,3 +693,97 @@ ggplot(diamonds, aes(carat, price)) +
   geom_point(alpha = 0.1) + 
   facet_bootstrap(n = 9, prop = 0.05)
 
+## -----------------------------------------------------------------------------
+p <- ggplot(mpg, aes(displ, hwy, colour = drv)) +
+  geom_point() +
+  scale_colour_discrete(
+    labels = c("4-wheel drive", "front wheel drive", "rear wheel drive")
+  )
+
+get_guide_data(p, "colour")
+
+## -----------------------------------------------------------------------------
+GuideKey <- ggproto(
+  "Guide", GuideAxis,
+  
+  # Some parameters are required, so it is easiest to copy the base Guide's
+  # parameters into our new parameters.
+  # We add a new 'key' parameter for our own guide.
+  params = c(GuideAxis$params, list(key = NULL)),
+  
+  # It is important for guides to have a mapped aesthetic with the correct name
+  extract_key = function(scale, aesthetic, key, ...) {
+    key$aesthetic <- scale$map(key$aesthetic)
+    names(key)[names(key) == "aesthetic"] <- aesthetic
+    key
+  }
+)
+
+## -----------------------------------------------------------------------------
+guide_key <- function(
+  aesthetic, value = aesthetic, label = as.character(aesthetic),
+  ...,
+  # Standard guide arguments
+  theme = NULL, title = waiver(), order = 0, position = waiver()
+) {
+  
+  key <- data.frame(aesthetic, .value = value, .label = label, ...)
+  
+  new_guide(
+    # Arguments passed on to the GuideKey$params field
+    key = key, theme = theme, title = title, order = order, position = position,
+    # Declare which aesthetics are supported
+    available_aes = c("x", "y"),
+    # Set the guide class
+    super = GuideKey
+  )
+}
+
+## ----key_example--------------------------------------------------------------
+ggplot(mpg, aes(displ, hwy)) +
+  geom_point() +
+  scale_x_continuous(
+    guide = guide_key(aesthetic = 2:6 + 0.5)
+  )
+
+## ----key_ggproto_edit---------------------------------------------------------
+# Same as before
+GuideKey <- ggproto(
+  "Guide", GuideAxis,
+  params = c(GuideAxis$params, list(key = NULL)),
+  extract_key = function(scale, aesthetic, key, ...) {
+    key$aesthetic <- scale$map(key$aesthetic)
+    names(key)[names(key) == "aesthetic"] <- aesthetic
+    key
+  },
+  
+  # New method to draw labels
+  build_labels = function(key, elements, params) {
+    position <- params$position
+    # Downstream code expects a list of labels
+    list(element_grob(
+      elements$text,
+      label = key$.label,
+      x = switch(position, left = 1, right = 0, key$x),
+      y = switch(position, top = 0, bottom = 1, key$y),
+      margin_x = position %in% c("left", "right"),
+      margin_y = position %in% c("top", "bottom"),
+      colour = key$colour
+    ))
+  }
+)
+
+## ----key_example_2------------------------------------------------------------
+ggplot(mpg, aes(displ, hwy)) +
+  geom_point() +
+  guides(
+    x = guide_key(
+      aesthetic = 2:6 + 0.5,
+      colour = c("red", "grey", "red", "grey", "red")
+    ),
+    x.sec = guide_key(
+      aesthetic = c(2, 4, 6), 
+      colour = c("tomato", "limegreen", "dodgerblue")
+    )
+  )
+
