@@ -1,5 +1,3 @@
-context("geom_boxplot")
-
 # thanks wch for providing the test code
 test_that("geom_boxplot range includes all outliers", {
   dat <- data_frame(x = 1, y = c(-(1:20) ^ 3, (1:20) ^ 3) )
@@ -10,6 +8,15 @@ test_that("geom_boxplot range includes all outliers", {
 
   expect_true(miny <= min(dat$y))
   expect_true(maxy >= max(dat$y))
+
+  # Unless specifically directed not to
+  p <- ggplot_build(ggplot(dat, aes(x, y)) + geom_boxplot(outliers = FALSE))
+
+  miny <- p$layout$panel_params[[1]]$y.range[1]
+  maxy <- p$layout$panel_params[[1]]$y.range[2]
+
+  expect_lte(maxy, max(dat$y))
+  expect_gte(miny, min(dat$y))
 })
 
 test_that("geom_boxplot works in both directions", {
@@ -77,7 +84,7 @@ test_that("boxplots with a group size >1 error", {
     geom_boxplot(stat = "identity")
 
   expect_equal(nrow(layer_data(p, 1)), 3)
-  expect_error(layer_grob(p, 1), "Can't draw more than one boxplot")
+  expect_snapshot_error(layer_grob(p, 1))
 })
 
 # Visual tests ------------------------------------------------------------
@@ -86,4 +93,7 @@ test_that("boxplot draws correctly", {
   expect_doppelganger("outlier colours",
     ggplot(mtcars, aes(x = factor(cyl), y = drat, colour = factor(cyl))) + geom_boxplot(outlier.size = 5)
   )
+  expect_doppelganger("staples",
+    ggplot(mtcars, aes(x = factor(cyl), y = drat, colour = factor(cyl))) + geom_boxplot(staplewidth = 0.5)
+  )
 })
