@@ -9,12 +9,11 @@ test_that("check h/v/abline transformed on basic projections", {
     geom_vline(xintercept = 3, colour = "red") +
     geom_hline(yintercept = 3, colour = "blue") +
     geom_abline(intercept = 0, slope = 1, colour = "purple") +
-    labs(x = NULL, y = NULL) +
-    coord_cartesian(expand = FALSE)
+    labs(x = NULL, y = NULL)
 
   expect_doppelganger(
     "cartesian lines intersect mid-bars",
-    plot
+    plot + coord_cartesian(expand = FALSE)
   )
   expect_doppelganger(
     "flipped lines intersect mid-bars",
@@ -27,16 +26,17 @@ test_that("check h/v/abline transformed on basic projections", {
 })
 
 test_that("curved lines in map projections", {
+  skip_if_not_installed("mapproj") # required for coord_map()
+  skip_if_not_installed("maps") # required for map_data()
   skip_if(packageVersion("base") < "3.5.0")
   nz <- subset(map_data("nz"), region == "North.Island ")
   nzmap <- ggplot(nz, aes(long, lat, group = group)) +
     geom_path() +
     geom_hline(yintercept = -38.6) + # roughly Taupo
-    geom_vline(xintercept = 176) +
-    coord_map()
+    geom_vline(xintercept = 176)
 
   expect_doppelganger("straight lines in mercator",
-    nzmap
+    nzmap + coord_map()
   )
   expect_doppelganger("lines curved in azequalarea",
     nzmap + coord_map(projection = 'azequalarea', orientation = c(-36.92, 174.6, 0))
