@@ -10,6 +10,22 @@ test_that("geom_path() throws meaningful error on bad combination of varying aes
   expect_snapshot_error(ggplotGrob(p))
 })
 
+test_that("repair_segment_arrow() repairs sensibly", {
+  group <- c(1,1,1,1,2,2)
+
+  ans <- repair_segment_arrow(arrow(ends = "last"), group)
+  expect_equal(ans$ends, rep(2L, 4))
+  expect_equal(as.numeric(ans$length), c(0, 0, 0.25, 0.25))
+
+  ans <- repair_segment_arrow(arrow(ends = "first"), group)
+  expect_equal(ans$ends, rep(1L, 4))
+  expect_equal(as.numeric(ans$length), c(0.25, 0, 0, 0.25))
+
+  ans <- repair_segment_arrow(arrow(ends = "both"), group)
+  expect_equal(ans$ends, c(1L, 3L, 2L, 3L))
+  expect_equal(as.numeric(ans$length), c(0.25, 0, 0.25, 0.25))
+})
+
 # Tests on stairstep() ------------------------------------------------------------
 
 test_that("stairstep() does not error with too few observations", {
@@ -79,6 +95,6 @@ test_that("NA linetype is dropped with warning", {
       "NA linetype",
       ggplot(df, aes(x, y)) + geom_path(linetype = NA)
     ),
-    "containing missing values"
+    "containing missing values or values outside the scale range"
   )
 })
