@@ -3,7 +3,7 @@ test_that("type argument is checked for proper input", {
     scale_colour_continuous(type = function() "abc")
   )
   expect_snapshot_error(
-    scale_fill_continuous(type = geom_point)
+    suppressWarnings(scale_fill_continuous(type = geom_point))
   )
   expect_snapshot_error(
     scale_colour_binned(type = function(...) scale_colour_binned(aesthetics = c("fill", "point_colour")))
