@@ -12,3 +12,15 @@ test_that("message + continuous for unknown type", {
   expect_message(scale <- find_scale("colour", x), "ggplot2_foo")
   expect_s3_class(scale, "ScaleContinuous")
 })
+
+test_that("find_scale gives sensible calls to scales", {
+  expect_equal(
+    find_scale("x", 1)$call,
+    quote(scale_x_continuous())
+  )
+
+  expect_equal(
+    find_scale("colour", "A")$call,
+    quote(scale_colour_discrete())
+  )
+})
